//Derek van Westrum (based on work by Natalya Dikovitskaya)
//UniTimeSeries.java

import java.applet.Applet;
import java.awt.*;
import java.awt.event.*;
import java.net.*;
import java.io.*;
import graph.*;

public class UniTimeSeries extends Applet {
    private Button submitButton = new Button( " Plot " );
    private Choice horiz_varList = new Choice();
    private Choice vert_varList = new Choice();
    private String stationName = null;
    private String stationNumber = "-1";
    private String stationType = null;
    private BorderLayout layout = new BorderLayout();
    private Graph2D graph = new Graph2D();
    private Axis x = new Axis( Axis.BOTTOM );
    private Axis y = new Axis( Axis.LEFT );
    private int x_col;
    private int y_col;
    private float x_min;
    private float x_max;
    private double x_fill_value;
    private float y_min;
    private float y_max;
    private double y_fill_value;

    public void init() {
	setLayout( layout );
	String s = "key";
	
	//get station number
	stationName = getParameter( "station" ); 
	stationNumber = getParameter( "station_num" ); 
	stationType = getParameter( "station_type" ); 

	//Create a horizontal variable list and display it
	horiz_varList.addItem( "Variable" );
	horiz_varList.addItem( "Date" );
	horiz_varList.addItem( "Lat" );
	horiz_varList.addItem( "Lon");
	horiz_varList.addItem( "AirTemp" );
	horiz_varList.addItem( "SLPress" );
	horiz_varList.addItem( "WindDir" );
	horiz_varList.addItem( "WindSpd" );
	horiz_varList.addItem( "TotCloud" );
	horiz_varList.addItem( "LowCloud" );
	horiz_varList.addItem( "RelHumid" );
	horiz_varList.addItem( "DewTemp" );
	horiz_varList.addItem( "WetBulbTemp" );
	horiz_varList.addItem( "VaporPress" );
	horiz_varList.addItem( "Precip" );
	horiz_varList.addItem( "SurfTemp" );
	horiz_varList.addItem( "SeaSurfTemp" );
	//Create a vertical variable list and display it
	vert_varList.addItem( "Variable" );
	vert_varList.addItem( "Date" );
	vert_varList.addItem( "Lat" );
	vert_varList.addItem( "Lon");
	vert_varList.addItem( "AirTemp" );
	vert_varList.addItem( "SLPress" );
	vert_varList.addItem( "WindDir" );
	vert_varList.addItem( "WindSpd" );
	vert_varList.addItem( "TotCloud" );
	vert_varList.addItem( "LowCloud" );
	vert_varList.addItem( "RelHumid" );
	vert_varList.addItem( "DewTemp" );
	vert_varList.addItem( "WetBulbTemp" );
	vert_varList.addItem( "VaporPress" );
	vert_varList.addItem( "Precip" );
	vert_varList.addItem( "SurfTemp" );
	vert_varList.addItem( "SeaSurfTemp" );
	
	Panel p = new Panel();
	p.add( "South", new Label( "X axis: " ) );
	p.add( horiz_varList );
	p.add( "South", new Label( "  Y axis: " ) );
	p.add( vert_varList );
	p.add( "South", new Label( "  " ) );
	
	//The Button for submission
	p.add( submitButton );
	
	//Add the panel to the Applet
	add( "North", p );
	
	//Create a graph and add it to the applet
	graph.borderTop    = 30;
	graph.borderBottom = 10;
	graph.borderRight  = 45;
	graph.borderLeft  = 45;
	add( "Center", graph );
	
	//create settings for the graph
	//graph.drawzero = false;
	graph.drawgrid = false;
	
    }
    
    public boolean action( Event event, Object arg ) {
	if ( event.target == submitButton ) {
	    DataSet dataSet = null;
	    
	    clearGraph();
	    
	    //Get the selected variables
	    int x_index = horiz_varList.getSelectedIndex();
	    int y_index = vert_varList.getSelectedIndex();
	    axisParamSetup( x_index, y_index) ; 
	    
	    String fileLocation = null;
	    if (stationType.equals( "russian_ship" )) {
		fileLocation = new String( 
		      "../../../../DATA/FLOATING_PLATFORMS/RUSSIAN_SHIP/uni." );
		fileLocation= fileLocation.concat( stationName);
	    } else if (stationType.equals( "russian_drift" )) {
		fileLocation = new String( 
		      "../../../../DATA/FLOATING_PLATFORMS/RUSSIAN_DRIFT/uni." );
		fileLocation= fileLocation.concat( stationName);
	    } else if (stationType.equals( "russian_drift_monthly" )) {
		fileLocation = new String( 
		      "../../../../DATA/FLOATING_PLATFORMS/RUSSIAN_DRIFT/uni.monthly." );
		fileLocation= fileLocation.concat( stationName);
	    } else if (stationType.equals( "western_drift" )) {
		fileLocation = new String( 
		      "../../../../DATA/FLOATING_PLATFORMS/WESTERN_DRIFT/FORMATTED_DATA/uni." );
		fileLocation= fileLocation.concat( stationName);
	    } else if (stationType.equals( "russian_stations" )) {
		fileLocation = new String( 
		      "../../../../DATA/COASTAL_STATIONS/RUSSIAN_STATIONS/uni." );
		fileLocation= fileLocation.concat( stationName);
		fileLocation= fileLocation.concat( "." + stationNumber );
	    } else if (stationType.equals( "western_stations" )) {
		fileLocation = new String( 
		      "../../../../DATA/COASTAL_STATIONS/WESTERN_STATIONS/uni." );
		fileLocation= fileLocation.concat( stationName);
		fileLocation= fileLocation.concat( "." + stationNumber );
	    }
	    fileLocation= fileLocation.concat( ".dat");

	    //settings for the graph
	    graph.setDataBackground( getBackground() );
	    graph.setGraphBackground( new Color(204,153,102) );
	    
	    //Create cross markers
	    Markers markers = new Markers();
	    boolean [] draw = { true, true, false, false, true, true };
	    int [] xm = { -2, 2, 2, 0, 0, 0 };
	    int [] ym = { 0, 0, 0, 2, -2, 2 };
	    markers.AddMarker( 6, draw, xm, ym );
	    graph.setMarkers( markers );
	    
	    try {
		URL url = new URL( getDocumentBase(), fileLocation );
		if (( x_col == -1) || (y_col == -1)) {
		    dataSet = graph.loadFile_JulianDate( url, x_col, y_col); 
		} else {
		    dataSet = graph.loadFile( url, x_col, y_col); 
		}
		if ( dataSet != null ) {
		    //create settings for displaying the data
		    dataSet.linestyle = 0;
		    dataSet.marker = 1;
		    dataSet.markerscale = 2;
		    dataSet.markercolor = new Color(0,51,102);
		    //attach data to the axes, attach the axes to graph
		    x.attachDataSet( dataSet );
		    y.attachDataSet( dataSet );
		    x.minor_tic_count = 10;
		    y.minor_tic_count = 10;
		    x.minimum = x_min;
		    x.maximum = x_max;
		    y.minimum = y_min;
		    y.maximum = y_max;
		    x.fill_value = x_fill_value;
		    y.fill_value = y_fill_value;
		    x.force_end_labels = true;
		    y.force_end_labels = true;
		    graph.attachAxis( x );
		    graph.attachAxis( y );
		}
	    }
	    catch( IOException e ) { System.out.println( e ); }
	}
	/* get it to redraw.. */
	graph.repaint();
	graph.invalidate();
	
	return true;
    }
    
    public void axisParamSetup(int x_index, int y_index)  {
	/* Note that min/max of axes are usually both set to zero.  This
	 *forces autoscaling.  They're left here though, in case you want to
	 * hard wire them for whatever reason... */
	
	switch (x_index) {
	case 1:
	    x_col = -1;
	    x_min = 0;
	    x_max = 0;
	    x.setTitleText( "Year" ); 
	    break;
	case 2:
	    x_col = 7;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 99.99;
	    x.setTitleText( "Latitude (decimal deg.)" );
	    break;
	case 3:
	    x_col = 8;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 999.99;
	    x.setTitleText( "Longitude (decimal deg.)" );
	    break;
	case 4:
	    x_col = 9;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 999.99;
	    x.setTitleText( "Air Temperature (deg. C)" );
	    break;
	case 5:
	    x_col = 10;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 9999.9;
	    x.setTitleText( "SL Pressure (mb)" );
	    break;
	case 6:
	    x_col = 11;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 999.9;
	    x.setTitleText( "Wind Direction (deg.)" );
	    break;
	case 7:
	    x_col = 12;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 999.9;
	    x.setTitleText( "Wind Speed (m/s)" );
	    break;
	case 8:
	    x_col = 13;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 99.9;
	    x.setTitleText( "Total Cloud Cover (tenths)" );
	    break;
	case 9:
	    x_col = 14;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 99.9;
	    x.setTitleText( "Low Cloud Cover(tenths)" );
	    break;
	case 10: 
	    x_col = 15;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 999.9;
	    x.setTitleText( "Relaltive Humidity (%)" );
	    break;
	case 11:
	    x_col = 16;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 999.99;
	    x.setTitleText( "Dew Temperature (deg. C)" );
	    break;
	case 12:
	    x_col = 17;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 999.99;
	    x.setTitleText( "Wet Bulb Temperature (deg. C)" );
	    break;
	case 13:
	    x_col = 18;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 9999.9;
	    x.setTitleText( "Vapor Pressure (mbar)" );
	    break;
	case 14:
	    x_col = 19;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = -1;
	    x.setTitleText( "Precipitation (mm)" );
	    break;
	case 15:
	    x_col = 20;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 999.99;
	    x.setTitleText( "Surface Temperature (deg. C)" );
	    break;
	case 16:
	    x_col = 21;
	    x_min = 0;
	    x_max = 0;
	    x_fill_value = 999.99;
	    x.setTitleText( "Sea Surface Temperature (deg. C)" );
	    break;
	}
	switch (y_index) {
	case 1:
	    y_col = -1;
	    y_min = 0;
	    y_max = 0;
	    y.setTitleText( "Year" ); 
	    break;
	case 2:
	    y_col = 7;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 99.99;
	    y.setTitleText( "Latitude (decimal deg.)" );
	    break;
	case 3:
	    y_col = 8;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 999.99;
	    y.setTitleText( "Longitude (decimal deg.)" );
	    break;
	case 4:
	    y_col = 9;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 999.99;
	    y.setTitleText( "Air Temperature (deg. C)" );
	    break;
	case 5:
	    y_col = 10;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 9999.9;
	    y.setTitleText( "SL Pressure (mb)" );
	    break;
	case 6:
	    y_col = 11;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 999.9;
	    y.setTitleText( "Wind Direction (deg.)" );
	    break;
	case 7:
	    y_col = 12;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 999.9;
	    y.setTitleText( "Wind Speed (m/s)" );
	    break;
	case 8:
	    y_col = 13;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 99.9;
	    y.setTitleText( "Total Cloud Cover (tenths)" );
	    break;
	case 9:
	    y_col = 14;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 99.9;
	    y.setTitleText( "Low Cloud Cover(tenths)" );
	    break;
	case 10: 
	    y_col = 15;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 999.9;
	    y.setTitleText( "Relaltive Humidity (%)" );
	    break;
	case 11:
	    y_col = 16;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 999.99;
	    y.setTitleText( "Dew Temperature (deg. C)" );
	    break;
	case 12:
	    y_col = 17;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 999.99;
	    y.setTitleText( "Wet Bulb Temperature (deg. C)" );
	    break;
	case 13:
	    y_col = 18;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 9999.9;
	    y.setTitleText( "Vapor Pressure (mbar)" );
	    break;
	case 14:
	    y_col = 19;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = -1;
	    y.setTitleText( "Precipitation (mm)" );
	    break;
	case 15:
	    y_col = 20;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 999.99;
	    y.setTitleText( "Surface Temperature (deg. C)" );
	    break;
	case 16:
	    y_col = 21;
	    y_min = 0;
	    y_max = 0;
	    y_fill_value = 999.99;
	    y.setTitleText( "Sea Surface Temperature (deg. C)" );
	    break;
	}
    }
    
    private void clearGraph()
    {
	graph.detachAxes();
	graph.detachDataSets();
	graph.setGraphBackground( getBackground() );
    }
}



